@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Ustawienia sieci</translation>
+        <translation>Ustawienia sieci</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Wykrywanie sieci</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Najpierw wyłącz &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Tryb samolotowy&lt;/a&gt;, aby połączyć się z siecią bezprzewodową</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>Konflikt IP</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Sieć</translation>
+        <translation>Sieć</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Połączenie przewodowe %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Połączenie PPPoE %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Łączenie z &quot;%1&quot;</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; połączono</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; rozłączono</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie można połączyć się z &quot;%1&quot;, sprawdź router lub kabel sieciowy.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie można połączyć się z &quot;%1&quot;, przybliż się do routera bezprzewodowego</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Połączenie nieudane, nie można połączyć się z &quot;%1&quot;, błędne hasło</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Wymagane jest hasło, aby połączyć się z &quot;%1&quot;</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie można znaleźć sieci WLAN &quot;%1&quot; 802.11</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Aby połączyć się z &quot;%1&quot;, skonfiguruj informacje uwierzytelniające</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Hasło</translation>
+        <translation>Hasło</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Hasło prywatne</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>klucz</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Hasło proxy</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Hasło grupy</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Nazwa użytkownika</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Nazwa (SSID)</translation>
+        <translation>Nazwa (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Anuluj</translation>
+        <translation>Anuluj</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Połącz</translation>
+        <translation>Połącz</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Wyłącz połączenie przewodowe</translation>
+        <translation>Wyłącz połączenie przewodowe</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Włącz połączenie przewodowe</translation>
+        <translation>Włącz połączenie przewodowe</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Wyłącz połączenie bezprzewodowe</translation>
+        <translation>Wyłącz połączenie bezprzewodowe</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Włącz połączenie bezprzewodowe</translation>
+        <translation>Włącz połączenie bezprzewodowe</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Wyłącz sieć</translation>
+        <translation>Wyłącz sieć</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Włącz sieć</translation>
+        <translation>Włącz sieć</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyłącz VPN</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Włącz VPN</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyłącz proxy systemowe</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Włącz proxy systemowe</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Ustawienia sieci</translation>
+        <translation>Ustawienia sieci</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Uruchomiono wiele usług</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Połączono z: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy systemowe włączone</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Połączono</translation>
+        <translation>Połączono</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Sieć wyłączona</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Kabel sieciowy odłączony</translation>
+        <translation>Kabel sieciowy odłączony</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Nie połączono</translation>
+        <translation>Nie połączono</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Łączenie</translation>
+        <translation>Łączenie</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Połączono, brak dostępu do Internetu</translation>
+        <translation>Połączono, brak dostępu do Internetu</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Połączenie nieudane</translation>
+        <translation>Połączenie nieudane</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>Konflikt IP</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Sieć bezprzewodowa</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 połączono</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Wył</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Sieć przewodowa</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Sieć</translation>
+        <translation>Sieć</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy systemowe</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfiguracja VPN jest nieprawidłowa lub wystąpił błąd połączenia. &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Przejdź do Centrum kontroli&lt;/a&gt;, aby zdiagnozować problem.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Sieć przewodowa</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Sieć bezprzewodowa</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Połącz z siecią ukrytą</translation>
+        <translation>Połącz z siecią ukrytą</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Moje sieci</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Inne sieci</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Sieć</translation>
+        <translation>Sieć</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
