@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ug">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">تور تەڭشىكى </translation>
+        <translation>تور تەڭشىكى</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>تورنى تەكشۈرۈش</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>كۆكچىش ئىقتىدارىنى ئىشلەتمەكچى بولسىڭىز، ئاۋۋال &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;ئۇچۇش ھالىتى&lt;/a&gt; نى تاقاڭ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP ئادرېس توقۇنۇشۇپ قالدى</translation>
+        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">تور</translation>
+        <translation>تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلىنىۋاتىدۇ</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلاندى</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» دىن ئۈزۈلدى</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلىيالمىدى، روتېر ياكى تور سىمىڭىزنى تەكشۈرۈڭ</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلىيالمىدى ،سىمسىز روتېرغا يىقىنلىشىپ سىناپ بىقىڭ</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>ئۇلانمىدى،  «%1» غا كىرەلمىدى، پارول خاتا</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلاش ئۈچۈن پارول كېتىدۇ</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» 802.11 WLAN تورىنى تاپالمىدى</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>«%1» غا ئۇلاش ئۈچۈن كىرگەندىن كېيىن دەلىللەش ئۇچۇرلىرىنى سەپلىشىڭىز كېرەك</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">پارولنى كىرگۈزۈڭ</translation>
+        <translation>پارول كىرگۈزۈڭ</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>شەخسىي پارول</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>ئاچقۇچ</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>ۋاكالەتچى پارولى</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>گۇرۇپپا پارول</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>ئىشلەتكۈچى نامىنى كىرگۈزۈڭ</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">تور نامىنى كىرگۈزۈڭ（SSID）</translation>
+        <translation>تور نامىنى كىرگۈزۈڭ（SSID）</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">بىكار قىلىش</translation>
+        <translation>بىكار قىلىش</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">ئۇلاش</translation>
+        <translation>ئۇلاش</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">سىملىق تورنى تاقاش</translation>
+        <translation>سىملىق تورنى تاقاش</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">سىملىق تورنى ئېچىش</translation>
+        <translation>سىملىق تورنى ئېچىش</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">سىمسىز تورنى تاقاش</translation>
+        <translation>سىمسىز تورنى تاقاش</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">سىمسىز تورنى ئېچىش</translation>
+        <translation>سىمسىز تورنى ئېچىش</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">تورنى تاقاش</translation>
+        <translation>تورنى تاقاش</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">تورنى قوزغىتىش </translation>
+        <translation>تورنى ئېچىش</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNنى تاقاش</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNنى ئېچىش</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>سىستېما ۋاكالەتچىلىكىنى تاقاش</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>سىستېما ۋاكالەتچىلىكىنى ئېچىش</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">تور تەڭشىكى </translation>
+        <translation>تور تەڭشىكى</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>كۆپ مۇلازىمەت ئېچىلدى</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation> %1 غا ئۇلاندى</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>سىستېما ۋاكالەتچىلىكى ئېچىلدى</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">ئۇلاندى</translation>
+        <translation>ئۇلاندى</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>تورنى تاقاش</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">تور سىمى ئۇلانمىغان </translation>
+        <translation>تور سىمى ئۇلانمىغان </translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">ئۇلانمىدى</translation>
+        <translation>ئۇلانمىدى</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">ئۇلىنىۋاتىدۇ</translation>
+        <translation>ئۇلىنىۋاتىدۇ</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
+        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">ئۇلىنىش مەغلۇپ بولدى</translation>
+        <translation>ئۇلانمىدى</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP ئادرېس توقۇنۇشۇپ قالدى</translation>
+        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">سىمسىز تور</translation>
+        <translation>سىمسىز تور</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation> %1 غا ئۇلاندى</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>تاقاش</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">سىملىق تور</translation>
+        <translation>سىملىق تور</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">تور</translation>
+        <translation>تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>سىستېما ۋاكالەتچىلىكى</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN سەپلىمىسى ئۇلانمىغان ياكى ئۇلىنالمىغان، بۇ يەرنى چېكىپ &lt;a style=\&quot;text-decoration: none;\&quot; href=\&quot;go to the control center\&quot;&gt; &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;كونترول مەركىزىگە كىرىپ &lt;/a&gt;  تەكشۈرۈڭ.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">سىملىق تور</translation>
+        <translation>سىملىق تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">سىمسىز تور</translation>
+        <translation>سىمسىز تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">يوشۇرۇن تورغا ئۇلاش</translation>
+        <translation>يوشۇرۇن تورغا ئۇلاش</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>باشقا تور</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">تور</translation>
+        <translation>تور</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
