@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ru">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>Bubble</name>
     <message>
@@ -12,290 +10,290 @@
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Если вы хотите подключиться к беспроводной сети, сначала отключите &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Режим самолёта&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Конфликт IP-адресов</translation>
+        <translation>Конфликт IP-адресов</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Сеть</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 соединено</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Пароль</translation>
+        <translation>Пароль</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>ключ</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Пароль прокси</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Имя пользователя</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Имя (SSID)</translation>
+        <translation>Имя (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Отмена</translation>
+        <translation>Отмена</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Подключить</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Отключить проводное соединение</translation>
+        <translation>Отключить проводное соединение</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Включить проводное соединение</translation>
+        <translation>Включить проводное соединение</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Отключить проводное соединение</translation>
+        <translation>Отключить беспроводное соединение</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Включить проводное соединение</translation>
+        <translation>Включите беспроводное соединение</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Отключить сеть</translation>
+        <translation>Отключить сеть</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Включить сеть</translation>
+        <translation>Включить сеть</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Отключить VPN</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Включить VPN</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Отключить системный прокси</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Включить системный прокси</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Настройки сети</translation>
+        <translation>Настройки сети</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Запущено несколько сервисов</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Включен системный прокси</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Подключено</translation>
+        <translation>Подключено</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Сеть отключена</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Сетевой кабель отключен</translation>
+        <translation>Сетевой кабель отключен</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Не подключено</translation>
+        <translation>Не подключено</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Соединение</translation>
+        <translation>Соединение</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Подключено, без доступа к Интернету</translation>
+        <translation>Подключено, но нет доступа к Интернету</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Ошибка подключения</translation>
+        <translation>Ошибка подключения</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Конфликт IP-адресов</translation>
+        <translation>Конфликт IP-адресов</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Беспроводная сеть</translation>
+        <translation>Беспроводная сеть</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Выкл.</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Проводная сеть</translation>
+        <translation>Проводная сеть</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Сеть</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Системный прокси</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Конфигурация VPN не подключена или не удалось подключиться. Пожалуйста, обратитесь в &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Центр управления&lt;/a&gt; для проверки.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Проводная сеть</translation>
+        <translation>Проводная сеть</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Беспроводная сеть</translation>
+        <translation>Беспроводная сеть</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Подключиться к скрытой сети</translation>
+        <translation>Подключение к скрытой сети</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Мои сети</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Прочие сети</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
